@@ -16,11 +16,10 @@ from expression.system import CancellationToken, OperationCanceledError
 TSource = TypeVar("TSource")
 
 Continuation = Callable[[TSource], None]
+Callbacks = Callable[[Continuation[TSource], Continuation[Exception], Continuation[OperationCanceledError]], None]
 
 
-def from_continuations(
-    callback: Callable[[Continuation[TSource], Continuation[Exception], Continuation[OperationCanceledError]], None]
-) -> Awaitable[TSource]:
+def from_continuations(callback: Callbacks[TSource]) -> Awaitable[TSource]:
     """Creates an asynchronous computation that captures the current
     success, exception and cancellation continuations. The callback must
     eventually call exactly one of the given continuations.
@@ -33,7 +32,7 @@ def from_continuations(
         An asynchronous computation that provides the callback with the
         current continuations.
     """
-    future: Future[Any] = asyncio.Future()
+    future: "Future[TSource]" = asyncio.Future()
 
     def done(value: TSource) -> None:
         future.set_result(value)
@@ -45,7 +44,7 @@ def from_continuations(
         future.cancel()
 
     callback(done, error, cancel)
-    return asyncio.ensure_future(future)
+    return future
 
 
 def start(computation: Awaitable[Any], token: Optional[CancellationToken] = None) -> None:
@@ -67,9 +66,11 @@ def start(computation: Awaitable[Any], token: Optional[CancellationToken] = None
 
 
 def start_immediate(computation: Awaitable[Any], token: Optional[CancellationToken] = None) -> None:
+    """Runs an asynchronous computation, starting immediately on the
+    current operating system thread."""
     task = asyncio.create_task(computation)
 
-    def cb():
+    def cb() -> None:
         task.cancel()
 
     if token:
@@ -77,7 +78,7 @@ def start_immediate(computation: Awaitable[Any], token: Optional[CancellationTok
     return None
 
 
-def run_synchronous(computation: Awaitable[TSource]) -> TSource:
+def run_synchronously(computation: Awaitable[TSource]) -> TSource:
     """Runs the asynchronous computation and await its result."""
     return asyncio.run(computation)
 
@@ -92,12 +93,22 @@ async def sleep(msecs: int) -> None:
     time. This is scheduled using a System.Threading.Timer object. The
     operation will not block operating system threads for the duration
     of the wait."""
-    return await asyncio.sleep(msecs / 1000.0)
+    await asyncio.sleep(msecs / 1000.0)
 
 
 async def empty() -> None:
     """Async no-op"""
-    pass
+
+
+def from_result(result: TSource) -> Awaitable[TSource]:
+    """Creates a async operation that's completed successfully with the
+    specified result."""
+
+    async def from_result(result: TSource) -> TSource:
+        """Async return value"""
+        return result
+
+    return from_result(result)
 
 
 __all__ = [
@@ -108,4 +119,5 @@ __all__ = [
     "sleep",
     "start",
     "start_immediate",
+    "run_synchronously",
 ]
