@@ -1,9 +1,9 @@
 """Option module.
 
 Contains a collection of static methods (functions) for operating on
-options. All functions takes the source as the last curried
-argument, i.e all functions returns a function that takes the source
-sequence as the only argument.
+options. All functions takes the source as the last curried argument,
+i.e all functions returns a function that takes the source sequence as
+the only argument.
 """
 from __future__ import annotations
 
@@ -14,12 +14,10 @@ from typing import (
     Callable,
     Generator,
     Iterable,
-    Iterator,
     List,
     Optional,
     TypeVar,
     Union,
-    cast,
     get_origin,
     overload,
 )
@@ -194,7 +192,7 @@ class Some(Option[TSource]):
 
     def map2(self, mapper: Callable[[TSource, T2], TResult], other: Option[T2]) -> Option[TResult]:
         if isinstance(other, Some):
-            return Some(mapper(self._value, cast(Some[T2], other).value))
+            return Some(mapper(self._value, other.value))
         return Nothing
 
     def bind(self, mapper: Callable[[TSource], Option[TResult]]) -> Option[TResult]:
@@ -351,7 +349,7 @@ class Nothing_(Option[TSource], EffectError):
 
         return []
 
-    def __iter__(self) -> Iterator[TSource]:
+    def __iter__(self) -> Generator[TSource, TSource, TSource]:
         """Return iterator for the `Nothing` case.
 
         We basically want to return nothing, but we have to return
