@@ -18,9 +18,7 @@ from .match import Case, SupportsMatch
 from .pipe import pipe
 
 TSource = TypeVar("TSource")
-TSourceIn = TypeVar("TSourceIn", contravariant=True)
 TResult = TypeVar("TResult")
-TResultOut = TypeVar("TResultOut", covariant=True)
 TError = TypeVar("TError")
 
 # Underscore types are used for generic methods
@@ -192,7 +190,7 @@ class ResultException(EffectError):
         self.message = message
 
 
-class Error(Result[TSource, TError], ResultException):
+class Error(ResultException, Result[TSource, TError]):
     """The Error result case class."""
 
     def __init__(self, error: TError) -> None:
