@@ -1,5 +1,5 @@
 """Data structures that can be traversed from left to right, performing an action on each element."""
-from typing import Callable, Generator, List, TypeVar
+from typing import Callable, Generator, List, TypeVar, Union, cast
 
 from expression import effect
 from expression.collections import seq
@@ -16,14 +16,18 @@ def traverse(fn: Callable[[TSource], Result[TResult, TError]], lst: List[TSource
     Threads an applicative computation though a list of items.
     """
 
-    # flake8: noqa: T484
     @effect.result
-    def folder(head: TSource, tail: Result[List[TResult], TError]) -> Generator[TResult, TResult, List[TResult]]:
+    def folder(
+        head: TSource, tail: Result[List[TResult], TError]
+    ) -> Generator[Union[List[TResult], TResult], Union[List[TResult], TResult], List[TResult]]:
         """Same as:
         >>> fn(head).bind(lambda head: tail.bind(lambda tail: Ok([head] + tail)))
         """
+        h: TResult
+        t: List[TResult]
         h = yield from fn(head)
         t = yield from tail
+
         return [h] + t
 
     state: Result[List[TSource], TError] = Ok([])
@@ -34,4 +38,5 @@ def sequence(lst: List[Result[TSource, TError]]) -> Result[List[TSource], TError
     """Execute a sequence of result returning commands and collect the
     sequence of their response."""
 
-    return traverse(identity, lst)
+    fn = cast(Callable[[Result[TSource, TError]], Result[TSource, TError]], identity)
+    return traverse(fn, lst)
