@@ -2,7 +2,7 @@ from typing import Callable, overload
 
 import pytest
 
-from expression.core import curried
+from expression import curried
 
 
 def test_curried_simple():
